Module masked

Module masked 

Masked array support: a NumPy numpy.ma-compatible interface.

A masked array pairs a data buffer with a boolean mask indicating which elements are valid. Elements where the mask is true are considered invalid (masked out) and are excluded from aggregate operations such as MaskedArray::mean and MaskedArray::sum.

Structs

MaskedArray
A masked array of f64 values.

Functions

masked_array
Create a 1-D masked array from parallel data and mask vectors.
masked_less
Create a 1-D masked array with all elements below threshold masked.
register_masked_module
Register masked-array classes and functions into a PyO3 module.