pub struct PyUntypedArray(/* private fields */);Expand description
A safe, untyped wrapper for NumPy’s ndarray class.
Unlike PyArray<T,D>, this type does not constrain either element type T nor the dimensionality D.
This can be useful to inspect function arguments, but it prevents operating on the elements without further downcasts.
When both element type T and index type D are known, these values can be downcast to PyArray<T, D>. In addition,
PyArray<T, D> can be dereferenced to a PyUntypedArray and can therefore automatically access its methods.
Example
Taking PyUntypedArray can be helpful to implement polymorphic entry points:
use pyo3::exceptions::PyTypeError;
use numpy::{Element, PyUntypedArray, PyArray1, dtype};
use numpy::{PyUntypedArrayMethods, PyArrayMethods, PyArrayDescrMethods};
#[pyfunction]
fn entry_point(py: Python<'_>, array: &Bound<'_, PyUntypedArray>) -> PyResult<()> {
fn implementation<T: Element>(array: &Bound<'_, PyArray1<T>>) -> PyResult<()> {
/* .. */
Ok(())
}
let element_type = array.dtype();
if element_type.is_equiv_to(&dtype::<f32>(py)) {
let array = array.cast::<PyArray1<f32>>()?;
implementation(array)
} else if element_type.is_equiv_to(&dtype::<f64>(py)) {
let array = array.cast::<PyArray1<f64>>()?;
implementation(array)
} else {
Err(PyTypeError::new_err(format!("Unsupported element type: {}", element_type)))
}
}Trait Implementations
Sourceimpl PyTypeInfo for PyUntypedArray
impl PyTypeInfo for PyUntypedArray
Sourceconst NAME: &'static str = "PyUntypedArray"
const NAME: &'static str = "PyUntypedArray"
prefer using ::type_object(py).name() to get the correct runtime value
Sourceconst MODULE: Option<&'static str>
const MODULE: Option<&'static str>
prefer using ::type_object(py).module() to get the correct runtime value
Sourcefn type_object_raw<'py>(py: Python<'py>) -> *mut PyTypeObject
fn type_object_raw<'py>(py: Python<'py>) -> *mut PyTypeObject
Sourcefn is_type_of(ob: &Bound<'_, PyAny>) -> bool
fn is_type_of(ob: &Bound<'_, PyAny>) -> bool
object is an instance of this type or a subclass of this type.impl DerefToPyAny for PyUntypedArray