Masked array support: a NumPy numpy.ma-compatible interface.
A masked array pairs a data buffer with a boolean mask indicating which
elements are valid. Elements where the mask is true are considered
invalid (masked out) and are excluded from aggregate operations such as
MaskedArray::mean and MaskedArray::sum.
Structs
- Masked
Array - A masked array of
f64values.
Functions
- masked_
array - Create a 1-D masked array from parallel data and mask vectors.
- masked_
less - Create a 1-D masked array with all elements below
thresholdmasked. - register_
masked_ module - Register masked-array classes and functions into a PyO3 module.